# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .email import Email


class ContactsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from payabli import ContactsResponse

    ContactsResponse(
        contact_email="eric@martinezcoatings.com",
        contact_name="Eric Martinez",
        contact_phone="5555555555",
        contact_title="Owner",
    )
    """

    contact_email: typing_extensions.Annotated[typing.Optional[Email], FieldMetadata(alias="ContactEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Contact email address.
    """

    contact_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactName")] = (
        pydantic.Field(default=None)
    )
    """
    Contact name.
    """

    contact_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactPhone")] = (
        pydantic.Field(default=None)
    )
    """
    Contact phone number.
    """

    contact_title: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactTitle")] = (
        pydantic.Field(default=None)
    )
    """
    Contact title.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
