# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .is_success import IsSuccess
from .poi_device import PoiDevice
from .response_text import ResponseText


class CloudQueryApiResponse(UniversalBaseModel):
    """
    Object containing details about cloud devices and their registration history.
    """

    is_success: typing_extensions.Annotated[typing.Optional[IsSuccess], FieldMetadata(alias="isSuccess")] = None
    response_list: typing_extensions.Annotated[
        typing.Optional[typing.List[PoiDevice]], FieldMetadata(alias="responseList")
    ] = pydantic.Field(default=None)
    """
    List of devices and history of registration.
    """

    response_text: typing_extensions.Annotated[typing.Optional[ResponseText], FieldMetadata(alias="responseText")] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
